@@ -3,18 +3,12 @@
 
 //FontClock::FontClock(QColor &aColor, QString &aFormat, QFont &aFont, int aBlink1, int aBlink2, QWidget *parent) :
 //    QWidget(parent), m_font(aFont), m_color(aColor), m_format(aFormat), m_blink1(aBlink1), m_blink2(aBlink2)
-FontClock::FontClock(QColor &aColor, QFont &aFont, QString &aTime, QWidget *parent) :
-    QWidget(parent), m_font(aFont), m_color(aColor), m_text(aTime)
+FontClock::FontClock(QColor &aColor, QFont &aFont, QString &aTime, QSize &aSize) :
+    QWidget(0), m_font(aFont), m_color(aColor), m_text(aTime)
 {
-    QSize aa = parent->size();
-    resize(aa);
-//    setAttribute(Qt::WA_TranslucentBackground);
-
-//    setWindowOpacity(0.4);
-//    QPalette qp = palette();
-  //  QColor qback = qp.color(QPalette::Base);
-//    qback.setAlpha(100);
-  //  qp.setColor(QPalette::Base,qback );
+//    QSize aa = aSize;
+    setAttribute(Qt::WA_TranslucentBackground);
+    resize(aSize);
     calcFontSize();
     showTime(m_text);
 }
@@ -24,9 +18,6 @@ void FontClock::calcFontSize()
     int wd_width = size().width();
     int wd_hgt = size().height();
 
-//    QTime time = QTime::currentTime();
-//    m_text = time.toString(m_format);
-
     QString fFamily = m_font.family();
     // calc font size
     for (int i = 0; i < 200; i++)
@@ -48,27 +39,30 @@ void FontClock::calcFontSize()
 
 void FontClock::showTime(QString aTime)
 {
-/*    QTime time = QTime::currentTime();
-    m_text = time.toString(m_format);
-    if (m_blink1)
-    {
-        int lngt = m_text.length();
-        if ((time.second() % 2) == 0)
-        {
-            m_text[lngt-m_blink1] = ' ';
-            if (m_blink2)
-                m_text[lngt-m_blink2] = ' ';
-        }
-    }*/
     m_text = aTime;
     update();
 }
 
-void FontClock::paintEvent(QPaintEvent* /*event*/)
+void FontClock::paintEvent(QPaintEvent* event)
 {
+    Q_UNUSED(event);
     QPainter p(this);
     p.setFont(m_font);
     p.setPen(m_color);
 
-    p.drawText(rect(), Qt::AlignCenter, m_text);
+    p.drawText(rect(), Qt::AlignTop | Qt::AlignHCenter, m_text);
+}
+
+void FontClock::resizeEvent (QResizeEvent * event )
+{
+    Q_UNUSED(event);
+    calcFontSize();
+}
+
+void FontClock::rotate()
+{
+    int wd = size().width();
+    int hg = size().height();
+    resize(QSize(hg,wd));
+//    calcFontSize();
 }
